This package contains tool for simulating exoplanet atmospheric
emmission spectra with the correlated-k method.

In order to install the package but still make it editable, type the
following in the terminal:

pip install --editable .